@@ -99,47 +99,45 @@ struct SQLTests {
     "variant.sql",
   ]
 
-  let queriesForSpark41Only: [String] = [
-    "time.sql",
+  let queriesForSpark42Only: [String] = [
+    "time.sql"
   ]
 
-  #if !os(Linux)
-    @Test
-    func runAll() async throws {
-      let spark = try await SparkSession.builder.getOrCreate()
-      let MAX = Int32.max
-      for name in try! fm.contentsOfDirectory(atPath: path).sorted() {
-        guard name.hasSuffix(".sql") else { continue }
-        print(name)
-        if await !spark.version.starts(with: "4.") && queriesForSpark4Only.contains(name) {
-          print("Skip query \(name) due to the difference between Spark 3 and 4.")
-          continue
-        }
-        if await !spark.version.starts(with: "4.1") && queriesForSpark41Only.contains(name) {
-          print("Skip query \(name) due to the difference between Spark 4.0 and 4.1")
-          continue
-        }
+  @Test
+  func runAll() async throws {
+    let spark = try await SparkSession.builder.getOrCreate()
+    let MAX = Int32.max
+    for name in try! fm.contentsOfDirectory(atPath: path).sorted() {
+      guard name.hasSuffix(".sql") else { continue }
+      print(name)
+      if await !spark.version.starts(with: "4.") && queriesForSpark4Only.contains(name) {
+        print("Skip query \(name) due to the difference between Spark 3 and 4.")
+        continue
+      }
+      if await !spark.version.starts(with: "4.2") && queriesForSpark42Only.contains(name) {
+        print("Skip query \(name) due to the difference between Spark 4.1 and 4.2")
+        continue
+      }
 
-        let sql = try String(contentsOf: URL(fileURLWithPath: "\(path)/\(name)"), encoding: .utf8)
-        let result =
-          try await spark.sql(sql).showString(MAX, MAX, false).collect()[0].get(0) as! String
-        let answer = cleanUp(result.trimmingCharacters(in: .whitespacesAndNewlines))
-        if regenerateGoldenFiles {
-          let path =
-            "\(FileManager.default.currentDirectoryPath)/Tests/SparkConnectTests/Resources/queries/\(name).answer"
-          fm.createFile(atPath: path, contents: answer.data(using: .utf8)!, attributes: nil)
-        } else {
-          let expected = cleanUp(
-            try String(contentsOf: URL(fileURLWithPath: "\(path)/\(name).answer"), encoding: .utf8)
-          )
-          .trimmingCharacters(in: .whitespacesAndNewlines)
-          if answer != expected {
-            print("Try to compare normalized result.")
-            #expect(normalize(answer) == normalize(expected))
-          }
+      let sql = try String(contentsOf: URL(fileURLWithPath: "\(path)/\(name)"), encoding: .utf8)
+      let result =
+        try await spark.sql(sql).showString(MAX, MAX, false).collect()[0].get(0) as! String
+      let answer = cleanUp(result.trimmingCharacters(in: .whitespacesAndNewlines))
+      if regenerateGoldenFiles {
+        let path =
+          "\(FileManager.default.currentDirectoryPath)/Tests/SparkConnectTests/Resources/queries/\(name).answer"
+        fm.createFile(atPath: path, contents: answer.data(using: .utf8)!, attributes: nil)
+      } else {
+        let expected = cleanUp(
+          try String(contentsOf: URL(fileURLWithPath: "\(path)/\(name).answer"), encoding: .utf8)
+        )
+        .trimmingCharacters(in: .whitespacesAndNewlines)
+        if answer != expected {
+          print("Try to compare normalized result.")
+          #expect(normalize(answer) == normalize(expected))
         }
       }
-      await spark.stop()
     }
-  #endif
+    await spark.stop()
+  }
 }
